# src.gros_client package

## Subpackages

* [src.gros_client.common package](src.gros_client.common.md)
  * [Submodules](src.gros_client.common.md#submodules)
  * [src.gros_client.common.camera module](src.gros_client.common.md#module-src.gros_client.common.camera)
    * [`Camera`](src.gros_client.common.md#src.gros_client.common.camera.Camera)
      * [`Camera.__init__()`](src.gros_client.common.md#src.gros_client.common.camera.Camera.__init__)
      * [`Camera.video_stream_status`](src.gros_client.common.md#src.gros_client.common.camera.Camera.video_stream_status)
  * [src.gros_client.common.system module](src.gros_client.common.md#module-src.gros_client.common.system)
    * [`System`](src.gros_client.common.md#src.gros_client.common.system.System)
      * [`System.reboot()`](src.gros_client.common.md#src.gros_client.common.system.System.reboot)
      * [`System.shutdown()`](src.gros_client.common.md#src.gros_client.common.system.System.shutdown)
  * [Module contents](src.gros_client.common.md#module-src.gros_client.common)
* [src.gros_client.robot package](src.gros_client.robot.md)
  * [Submodules](src.gros_client.robot.md#submodules)
  * [src.gros_client.robot.car module](src.gros_client.robot.md#module-src.gros_client.robot.car)
    * [`Car`](src.gros_client.robot.md#src.gros_client.robot.car.Car)
      * [`Car.__init__()`](src.gros_client.robot.md#src.gros_client.robot.car.Car.__init__)
      * [`Car.move()`](src.gros_client.robot.md#src.gros_client.robot.car.Car.move)
      * [`Car.set_mode()`](src.gros_client.robot.md#src.gros_client.robot.car.Car.set_mode)
    * [`Mod`](src.gros_client.robot.md#src.gros_client.robot.car.Mod)
      * [`Mod.MOD_2_WHEEL`](src.gros_client.robot.md#src.gros_client.robot.car.Mod.MOD_2_WHEEL)
      * [`Mod.MOD_3_WHEEL`](src.gros_client.robot.md#src.gros_client.robot.car.Mod.MOD_3_WHEEL)
      * [`Mod.MOD_4_WHEEL`](src.gros_client.robot.md#src.gros_client.robot.car.Mod.MOD_4_WHEEL)
  * [src.gros_client.robot.human module](src.gros_client.robot.md#module-src.gros_client.robot.human)
    * [`Human`](src.gros_client.robot.md#src.gros_client.robot.human.Human)
      * [`Human.__init__()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.__init__)
      * [`Human.disable_debug_state()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.disable_debug_state)
      * [`Human.enable_debug_state()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.enable_debug_state)
      * [`Human.get_joint_limit()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.get_joint_limit)
      * [`Human.get_joint_states()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.get_joint_states)
      * [`Human.head()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.head)
      * [`Human.stand()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.stand)
      * [`Human.walk()`](src.gros_client.robot.md#src.gros_client.robot.human.Human.walk)
  * [src.gros_client.robot.robot_base module](src.gros_client.robot.md#module-src.gros_client.robot.robot_base)
    * [`RobotBase`](src.gros_client.robot.md#src.gros_client.robot.robot_base.RobotBase)
      * [`RobotBase.__init__()`](src.gros_client.robot.md#src.gros_client.robot.robot_base.RobotBase.__init__)
      * [`RobotBase.exit()`](src.gros_client.robot.md#src.gros_client.robot.robot_base.RobotBase.exit)
      * [`RobotBase.start()`](src.gros_client.robot.md#src.gros_client.robot.robot_base.RobotBase.start)
      * [`RobotBase.stop()`](src.gros_client.robot.md#src.gros_client.robot.robot_base.RobotBase.stop)
  * [Module contents](src.gros_client.robot.md#module-src.gros_client.robot)

## Module contents
